import * as i0 from '@angular/core';
import { InjectionToken, inject, Component, Input, input, Directive, Pipe, Inject, Injectable, makeEnvironmentProviders } from '@angular/core';
import { generateHTML } from '@tiptap/html';
import Bold from '@tiptap/extension-bold';
import Italic from '@tiptap/extension-italic';
import Strike from '@tiptap/extension-strike';
import Underline from '@tiptap/extension-underline';
import Document from '@tiptap/extension-document';
import Text from '@tiptap/extension-text';
import Paragraph from '@tiptap/extension-paragraph';
import History from '@tiptap/extension-history';
import ListItem from '@tiptap/extension-list-item';
import OrderedList from '@tiptap/extension-ordered-list';
import BulletList from '@tiptap/extension-bullet-list';
import Code from '@tiptap/extension-code';
import CodeBlockLowlight from '@tiptap/extension-code-block-lowlight';
import Link from '@tiptap/extension-link';
import Heading from '@tiptap/extension-heading';
import * as i1 from '@angular/platform-browser';
import { IMAGE_LOADER } from '@angular/common';
import { loadLocalessSync } from '@localess/js-client';

const LOCALESS_BROWSER_CONFIG = new InjectionToken('LOCALESS_BROWSER_CONFIG', {
    providedIn: 'root',
    factory: () => defaultBrowserConfig
});
const defaultBrowserConfig = {
    origin: '',
    spaceId: '',
    assetPathPrefix: '',
};

function findLink(links, link) {
    switch (link.type) {
        case "content": {
            const path = links[link.uri];
            if (path) {
                return '/' + path.fullSlug;
            }
            else {
                return '/not-found';
            }
        }
        case "url":
            return link.uri;
        default:
            return 'no-type';
    }
}

/**
 * @since 0.1.0
 * @deprecated starting with v0.2.0, it will be removed in future versions.
 * Please use SchemaComponent or SchemaWithInputComponent instead.
 */
class LocalessComponent {
    constructor() {
        this.config = inject(LOCALESS_BROWSER_CONFIG);
    }
    assetUrl(asset) {
        return this.config.assetPathPrefix + asset.uri;
    }
    findLink(links, link) {
        return findLink(links, link);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: LocalessComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.8", type: LocalessComponent, isStandalone: true, selector: "ll-component", host: { properties: { "attr.data-ll-id": "id()" } }, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: LocalessComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'll-component',
                    standalone: true,
                    template: '',
                    host: {
                        '[attr.data-ll-id]': 'id()'
                    },
                }]
        }] });

/**
 * Schema base component
 * @since v0.2.0
 */
class SchemaComponent {
    constructor() {
        this.config = inject(LOCALESS_BROWSER_CONFIG);
    }
    assetUrl(asset) {
        return this.config.assetPathPrefix + asset.uri;
    }
    findLink(links, link) {
        return findLink(links, link);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SchemaComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.8", type: SchemaComponent, isStandalone: true, selector: "ll-schema-component", host: { properties: { "attr.data-ll-id": "content()._id", "attr.data-ll-schema": "content()._schema || content().schema" } }, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SchemaComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'll-schema-component',
                    standalone: true,
                    template: '',
                    host: {
                        '[attr.data-ll-id]': 'content()._id',
                        '[attr.data-ll-schema]': 'content()._schema || content().schema'
                    },
                }]
        }] });

/**
 * Schema base component
 * @since v0.5.1
 */
class SchemaWithInputComponent {
    constructor() {
        this.config = inject(LOCALESS_BROWSER_CONFIG);
    }
    assetUrl(asset) {
        return this.config.assetPathPrefix + asset.uri;
    }
    findLink(link) {
        const links = this.links;
        if (links) {
            return findLink(links, link);
        }
        return '/not-found';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SchemaWithInputComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.8", type: SchemaWithInputComponent, isStandalone: true, selector: "ll-schema-with-input-component", inputs: { data: "data", links: "links" }, host: { properties: { "attr.data-ll-id": "data._id", "attr.data-ll-schema": "data._schema || data.schema" } }, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SchemaWithInputComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'll-schema-with-input-component',
                    standalone: true,
                    template: '',
                    host: {
                        '[attr.data-ll-id]': 'data._id',
                        '[attr.data-ll-schema]': 'data._schema || data.schema'
                    },
                }]
        }], propDecorators: { data: [{
                type: Input,
                args: [{ required: true }]
            }], links: [{
                type: Input,
                args: [{ required: false }]
            }] } });

/**
 * Schema base component
 * @since v0.5.1
 */
class SchemaWithSignalComponent {
    constructor() {
        this.config = inject(LOCALESS_BROWSER_CONFIG);
        this.data = input.required();
        this.links = input();
    }
    assetUrl(asset) {
        return this.config.assetPathPrefix + asset.uri;
    }
    findLink(link) {
        const links = this.links();
        if (links) {
            return findLink(links, link);
        }
        return '/not-found';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SchemaWithSignalComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "18.2.8", type: SchemaWithSignalComponent, isStandalone: true, selector: "ll-schema-with-signal-component", inputs: { data: { classPropertyName: "data", publicName: "data", isSignal: true, isRequired: true, transformFunction: null }, links: { classPropertyName: "links", publicName: "links", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.data-ll-id": "data()._id", "attr.data-ll-schema": "data()._schema || data().schema" } }, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SchemaWithSignalComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'll-schema-with-signal-component',
                    standalone: true,
                    template: '',
                    host: {
                        '[attr.data-ll-id]': 'data()._id',
                        '[attr.data-ll-schema]': 'data()._schema || data().schema'
                    },
                }]
        }] });

class ContentIdDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentIdDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: ContentIdDirective, isStandalone: true, selector: "[data-ll-id]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentIdDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[data-ll-id]',
                    standalone: true
                }]
        }] });
class ContentSchemaDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentSchemaDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: ContentSchemaDirective, isStandalone: true, selector: "[data-ll-schema]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentSchemaDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[data-ll-schema]',
                    standalone: true
                }]
        }] });
class ContentFieldDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentFieldDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: ContentFieldDirective, isStandalone: true, selector: "[data-ll-field]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentFieldDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[data-ll-field]',
                    standalone: true
                }]
        }] });
class ContentDirective {
    constructor(el) {
        this.el = el;
        this.content = input.required({ alias: 'llContent' });
    }
    ngOnInit() {
        this.el.nativeElement.setAttribute('data-ll-id', this.content()._id);
        this.el.nativeElement.setAttribute('data-ll-schema', this.content()._schema || this.content().schema);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "18.2.8", type: ContentDirective, isStandalone: true, selector: "[llContent]", inputs: { content: { classPropertyName: "content", publicName: "llContent", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[llContent]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class AssetPipe {
    constructor(config) {
        this.config = config;
    }
    transform(asset) {
        return `${this.config.assetPathPrefix}${asset.uri}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: AssetPipe, deps: [{ token: LOCALESS_BROWSER_CONFIG }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: AssetPipe, isStandalone: true, name: "llAsset" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: AssetPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'llAsset',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [LOCALESS_BROWSER_CONFIG]
                }] }] });

class LinkPipe {
    transform(links, link) {
        return findLink(links, link);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: LinkPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: LinkPipe, isStandalone: true, name: "llLink" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: LinkPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'llLink',
                    standalone: true
                }]
        }] });

class RichTextToHtmlPipe {
    transform(value) {
        if (value === undefined || value === null)
            return '';
        if (typeof value === 'string')
            return value;
        return generateHTML(value, [
            Document,
            Text,
            Paragraph,
            Heading.configure({
                levels: [1, 2, 3, 4, 5, 6],
            }),
            Bold,
            Italic,
            Strike,
            Underline,
            History,
            ListItem,
            OrderedList,
            BulletList,
            Code,
            CodeBlockLowlight,
            Link,
        ]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: RichTextToHtmlPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: RichTextToHtmlPipe, isStandalone: true, name: "llRtToHtml" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: RichTextToHtmlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: "llRtToHtml",
                    standalone: true,
                }]
        }] });

class SafeHtmlPipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(html) {
        return this.sanitizer.bypassSecurityTrustHtml(html);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SafeHtmlPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: SafeHtmlPipe, isStandalone: true, name: "llSafeHtml" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: SafeHtmlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: "llSafeHtml",
                    standalone: true,
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class BrowserAssetService {
    constructor() {
        this.config = inject(LOCALESS_BROWSER_CONFIG);
        if (this.config.debug) {
            console.log('[Localess]BrowserAssetService', this.config);
        }
    }
    /**
     * Convert Asset to URL.
     * @param asset
     */
    link(asset) {
        if (typeof asset === 'string') {
            return `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/assets/${asset}`;
        }
        else {
            return `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/assets/${asset.uri}`;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BrowserAssetService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BrowserAssetService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BrowserAssetService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

function provideLocalessBrowser(options) {
    const { origin, spaceId, debug, enableSync } = options;
    if (origin === undefined || origin === '') {
        throw new Error('Localess Origin can\'t be empty');
    }
    if (spaceId === undefined || spaceId === '') {
        throw new Error('Localess Space ID can\'t be empty');
    }
    if (enableSync) {
        console.log('[Localess] enableSync', enableSync);
        loadLocalessSync(origin);
    }
    return [
        makeEnvironmentProviders([
            {
                provide: LOCALESS_BROWSER_CONFIG,
                useValue: {
                    origin,
                    spaceId,
                    debug,
                    assetPathPrefix: `${options.origin}/api/v1/spaces/${options.spaceId}/assets/`,
                },
            },
            {
                provide: IMAGE_LOADER,
                useValue: (config) => {
                    if (debug) {
                        console.log('[Localess]ImageLoader', config);
                    }
                    // optimize image for API assets
                    if (config.src.startsWith(`${origin}/api/v1/spaces/${spaceId}/assets/`) && config.width) {
                        return `${config.src}?w=${config.width}`;
                    }
                    else {
                        return config.src;
                    }
                },
            },
        ])
    ];
}

// Components

/**
 * Generated bundle index. Do not edit.
 */

export { AssetPipe, BrowserAssetService, ContentDirective, ContentFieldDirective, ContentIdDirective, ContentSchemaDirective, LOCALESS_BROWSER_CONFIG, LinkPipe, LocalessComponent, RichTextToHtmlPipe, SafeHtmlPipe, SchemaComponent, SchemaWithInputComponent, SchemaWithSignalComponent, defaultBrowserConfig, findLink, provideLocalessBrowser };
//# sourceMappingURL=localess-angular-browser.mjs.map
