import * as i0 from '@angular/core';
import { InjectionToken, inject, Injectable, makeEnvironmentProviders } from '@angular/core';
import * as i1 from '@angular/common/http';
export { localessClient } from '@localess/js-client';

const LOCALESS_SERVER_CONFIG = new InjectionToken('LOCALESS_SERVER_CONFIG', {
    providedIn: 'root',
    factory: () => defaultServerConfig
});
const defaultServerConfig = {
    origin: '',
    spaceId: '',
    token: '',
    assetPathPrefix: '',
};

class ServerAssetService {
    constructor() {
        this.config = inject(LOCALESS_SERVER_CONFIG);
        console.log('[Localess]ServerAssetService', this.config);
    }
    /**
     * Convert Asset to URL.
     * @param asset
     */
    link(asset) {
        if (typeof asset === 'string') {
            return `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/assets/${asset}`;
        }
        else {
            return `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/assets/${asset.uri}`;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerAssetService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerAssetService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerAssetService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

class ServerContentService {
    constructor(httpClient) {
        this.httpClient = httpClient;
        this.config = inject(LOCALESS_SERVER_CONFIG);
        console.log('[Localess]ServerContentService', this.config);
    }
    /**
     * Get all links
     * @returns {Observable<Links>}
     */
    getLinks(params) {
        let url = `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/links`;
        const clientParams = {};
        if (params?.kind) {
            clientParams['kind'] = params.kind;
        }
        if (params?.parentSlug) {
            clientParams['parentSlug'] = params.parentSlug;
        }
        if (params?.excludeChildren) {
            clientParams['excludeChildren'] = params.excludeChildren;
        }
        return this.httpClient.get(url, {
            params: {
                token: this.config.token,
                ...clientParams
            }
        });
    }
    /**
     * Get content by SLUG
     * @param slug{string} - Content SLUG
     * @param params{ContentFetchParams} - Fetch parameters
     * @returns {Observable<Content>}
     */
    getContentBySlug(slug, params) {
        let url = `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/contents/slugs/${slug}`;
        const clientParams = {};
        // Config
        if (this.config.version && this.config.version == 'draft') {
            clientParams['version'] = this.config.version;
        }
        // Params
        if (params?.version && params.version == 'draft') {
            clientParams['version'] = params.version;
        }
        if (params?.locale) {
            clientParams['locale'] = params.locale;
        }
        return this.httpClient.get(url, {
            params: {
                token: this.config.token,
                ...clientParams,
            }
        });
    }
    /**
     * Get content by ID
     * @param id{string} - Content ID
     * @param params{ContentFetchParams} - Fetch parameters
     * @returns {Observable<Content>}
     */
    getContentById(id, params) {
        let url = `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/contents/${id}`;
        const clientParams = {};
        // Config
        if (this.config.version && this.config.version == 'draft') {
            clientParams['version'] = this.config.version;
        }
        // Params
        if (params?.version && params.version == 'draft') {
            clientParams['version'] = params.version;
        }
        if (params?.locale) {
            clientParams['locale'] = params.locale;
        }
        return this.httpClient.get(url, {
            params: {
                token: this.config.token,
                ...clientParams
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerContentService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerContentService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerContentService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.HttpClient }] });

class ServerTranslationService {
    constructor(httpClient) {
        this.httpClient = httpClient;
        this.config = inject(LOCALESS_SERVER_CONFIG);
        console.log('[Localess]ServerTranslationService', this.config);
    }
    /**
     * Retrieve all Translations by Localess.
     */
    fetch(locale) {
        let url = `${this.config.origin}/api/v1/spaces/${this.config.spaceId}/translations/${locale}`;
        return this.httpClient.get(url, { params: { token: this.config.token } });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerTranslationService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerTranslationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: ServerTranslationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.HttpClient }] });

function provideLocalessServer(options) {
    if (options.origin === undefined || options.origin === '') {
        throw new Error('Localess Origin can\'t be empty');
    }
    if (options.spaceId === undefined || options.spaceId === '') {
        throw new Error('Localess Space ID can\'t be empty');
    }
    if (options.token === undefined || options.token === '') {
        throw new Error('Localess Token can\'t be empty');
    }
    const providers = [
        makeEnvironmentProviders([
            {
                provide: LOCALESS_SERVER_CONFIG,
                useValue: {
                    ...options,
                    assetPathPrefix: `${options.origin}/api/v1/spaces/${options.spaceId}/assets/`,
                },
            },
        ])
    ];
    return providers;
}

// Models

/**
 * Generated bundle index. Do not edit.
 */

export { LOCALESS_SERVER_CONFIG, ServerAssetService, ServerContentService, ServerTranslationService, defaultServerConfig, provideLocalessServer };
//# sourceMappingURL=localess-angular-server.mjs.map
